﻿# Redis TRADEMARK GUIDELINES

1. **OPEN SOURCE LICENSE VS. TRADEMARKS.** The three-clause BSD license gives you the right to redistribute and use the software in source and binary forms, with or without modification, under certain conditions. However, open source licenses like the three-clause BSD license do not address trademarks. Redis trademarks and brands need to be used in a way consistent with trademark law, and that is why we have prepared this policy – to help you understand what branding is allowed or required when using our software.

2. **PURPOSE** To outline the policy and guidelines for using the Redis trademark (“Mark”) and logo (“Logo”) by members of the Redis developer and user community.

3. **WHY IS THIS IMPORTANT?** The Mark and Logo are symbols of the quality and community support associated with the open source Redis. Trademarks protect not only its owners, but its users and the entire open source community. Our community members need to know that they can rely on the quality represented by the brand.  No one should use the Mark or Logo in any way that misleads anyone, either directly or by omission, or in any way that is likely to confuse or take advantage of the community, or constitutes unfair use. For example, you cannot say you are distributing Redis software when you are distributing a modified version of it, because people will be confused when they are not getting the same features and functionality they would get if they downloaded the software directly from us, or will think that the modified software is endorsed or sponsored by us or the community.  You also cannot use the Mark or Logo on your website or in connection with any services in a way that suggests that your website is an official Redis website or service, or that suggests that we endorse your website or services.

4. **PROPER USE OF THE Redis TRADEMARKS AND LOGO.** You may do any of the following:
    * a. When you use an unaltered, unmodified copy of open source Redis (the “Software”) as a data source for your application, you may use the Mark and Logo to identify your use. For avoidance of any doubt, the open source Redis software combined with, or integrated into, any other software program, including but not limited to software for offering Redis as a cloud service or orchestration software for offering Redis in containers is considered “modified” Redis software and does not entitle you to use the Mark or the Logo, except in a case of nominative use, as described below.
    * b. The Software is developed by and for the Redis community. If you are engaged in community advocacy, you can use the Mark but not the Logo in the context of showing support for the open source Redis project, provided that:
        * i. The Mark is used in a manner consistent with this policy.
        * ii. There is no commercial purpose behind the use and you are not offering Redis commercially under the same domain name.
        * iii. There is no suggestion that you are the creator or source of Redis, or that your project is approved, sponsored, or affiliated with us or the community.
        * iv. You must include attribution according to section 6.a. herein.
    * c. __Nominative Use__: Trademark law permits third parties the use of a mark to identify the trademark holder’s product or service so long as such use is not likely to cause unnecessary consumer or public confusion. This is referred to as a nominative or fair use. When you distribute, or offer an altered, modified or combined copy of the Software, such as in the case of a cloud service or a container service, you may engage in “nominative use” of the Mark, but this does not allow you to use the Logo.
    * d. Examples of Nominative Use:
        * i. Offering an XYZ software, which is an altered, modified or combined copy of the open source Redis software, including but not limited to offering Redis as a cloud service or as a container service, and while fully complying with the open source Redis API - you may only state that **"XYZ software is compatible with the Redis API"** No other term or description of your software is allowed.
        * ii. Offering an XYZ application, which uses an altered, modified or combined copy of the open source Redis software as a data source, including but not limited to using Redis as a cloud service or a container service, and while the modified Redis fully complies with the open source Redis API - you may only state that **"XYZ application is using a software which is compatible with the Redis API"**. No other term or description of your application is allowed.
        * iii. If, however, the offered XYZ software, or service based thereof, uses an altered, modified or combined copy of the open source Redis software that does not fully comply with the open source Redis API - you may not use the Mark and Logo at all.
        * iv. Finally, while our previous trademark policy suggested that the reference “XYZ Software for Redis” would be a permissible nominative use of the mark, after further consideration, such a use inappropriately suggests an endorsement or sponsorship by us and the community, which we believe creates an unreasonable likelihood of confusion, so this is no longer permitted.
5. **IMPROPER USE OF THE REDIS TRADEMARKS AND LOGOS**. Any use of the Mark
or Logo other than as expressly described as permitted above, is not permitted because we believe that it would likely cause impermissible public confusion. As an example, combining the open source Redis software with another software program, or orchestrating its operations (orchestrating replication, for example), may change its behavior in a non-trivial way and alter the user experience in a significant manner.  Absent our prior endorsement of any other use, you should expect that we will consider any such use as infringing our legal rights. Use of the Mark that we will likely consider infringing without permission for use include:
    * a. Altered or Combined Software. You may not use the Mark with any software distribution in which the open source Redis software has been altered, modified or combined with any other software program, including software for offering Redis as a cloud service or orchestration software for offering Redis in containers. In this context, phrases like “XYZ for Redis”, “Redis based”, “Redis compatible” are not allowed. However, provided that you meet the requirements of Nominative Use in sections 4.c. and 4.d. hereabove, you can state that **"XYZ software is compatible with the Redis API"**, or **"XYZ application is using a software which is compatible with the Redis API"**.
    * b. Entity Names. You may not form a company, use a company name, or create a software product or service name that includes the Mark or implies any that such company is the source or sponsor of Redis. If you wish to form an entity for a user or developer group, please contact us and we will be glad to discuss a license for a suitable name.
    * c. Class or Quality. You may not imply that you are providing a class or quality of Redis (e.g., "enterprise-class" or "commercial quality" or “fully managed”) in a way that implies Redis is not of that class, grade or quality, nor that other parties are not of that class, grade, or quality.
    * d. False or Misleading Statements. You may not make false or misleading statements regarding your use of Redis (e.g., "we wrote the majority of the code" or "we are major contributors" or "we are committers").
    * e. Domain Names and Subdomains. You must not use Redis or any confusingly similar phrase in a domain name or subdomain. For instance “www.Redishost.com” is not allowed. If you wish to use such a domain name for a user or developer group, please contact us and we will be glad to discuss a license for a suitable domain name. Because of the many persons who, unfortunately, seek to spoof, swindle or deceive the community by using confusing domain names, we must be very strict about this rule.
    * f. Websites. You must not use our Mark or Logo on your website in a way that suggests that your website is an official website or that we endorse your website.
    * g. Merchandise. You must not manufacture, sell or give away merchandise items, such as T-shirts and mugs, bearing the Mark or Logo, or create any mascot for Redis. If you wish to use the Mark or Logo for a user or developer group, please contact us and we will be glad to discuss a license to do this.
    * h. Variations, takeoffs or abbreviations. You may not use a variation of the Mark for any purpose. For example, the following are not acceptable:
        * i. Red
        * ii. MyRedis
        * iii. RedisHost
    * i. Rebranding. You may not change the Mark or Logo on a redistributed (unmodified) Software to your own brand or logo. You may not hold yourself out as the source of the Redis software, except to the extent you have modified it as allowed under the three-clause BSD license, and you make it clear that you are the source only of the modification.
    * j. Combination Marks. Do not use our Mark or Logo in combination with any other marks or logos. For example Foobar Redis, or the name of your company or product typeset to look like the Redis logo.
    * k. Web Tags. Do not use the Mark in a title or metatag of a web page to influence search engine rankings or result listings, rather than for discussion or advocacy of the Redis project.
6. **GENERAL USE INFORMATION.**
    * a. Attribution. The appropriate trademark symbol (i.e., TM or ® ) must appear at least with the first use of the Mark and all occurrences of the Logo. When you use the Mark or Logo, you must include a statement attributing ownership of the trademark to Redis Labs Ltd. For example, "Redis and the Redis logo are trademarks owned by Redis Labs Ltd. in the U.S. and other countries."
    * b. Capitalization. Always distinguish the Mark from surrounding text with at least initial capital letters or in all capital letters, e.g., as Redis or REDIS.
    * c. Adjective. Always use the Mark as an adjective modifying a noun, such as “the Redis software.”
    * d. Do not make any changes to the Logo. This means you may not add decorative elements, change the colors, change the proportions, distort it, add elements or combine it with other logos.
7. **NOTIFY US OF ABUSE.** Do not make any changes to the Logo. This means you may not add decorative elements, change the colors, change the proportions, distort it, add elements or combine it with other logos.
8. **MORE QUESTIONS?** If you have questions about this policy, or wish to request a license for any uses that are not specifically authorized in this policy, please contact us at legal@redislabs.com.

